<?php

/*

    GTPhoto2 - A multi user photo album
    Copyright (C) 2004-2005 Chris Kloosterman

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Author's Email Address:
        kloostec@gavintech.com
    Paper Mail:
        5945 Cassino Road
        Duncan, BC, V9L 4G5, Canada

*/

/*
This is the handler script
Its job is to ... handle stuff.  The basic flow of operation is as follows:
1) Initialize the page and set global variables
2) Set up the page's header and footer
3) Validate the input coming in if there is a validator
4) Output the page, unless there are errors
4a) If there are errors, go back to the previous page instead
5) print the footer to the page
*/

##################
# Initialization #
##################

# stuff to do when the page starts
# - start the page generation time counter
# - initialize the sql query counter
require_once("includes/page_start.php");

# global variables
require_once("includes/vars.php");
require_once("includes/version.php");

# functions that every page will use
require_once("includes/error_functions.php");
require_once("includes/clean_functions.php");
require_once("includes/date_functions.php");
require_once("includes/paginate_functions.php");
require_once("includes/data_functions.php");
require_once("includes/email_functions.php");
require_once("includes/javascript_functions.php");
require_once("includes/log_functions.php");

# sql wrappers for database functions (so that we can change db servers)
require_once("includes/sql_wrappers.php");

# session initialization stuff
require_once("includes/session.php");

# classes for the complex objects
require_once("includes/classes.php");

# start the database connection
require_once("includes/database.php");

# functions for login
require_once("includes/login.php");

# do login if required
require_once("includes/do_login.php");

# do the page log
require_once("includes/page_log.php");

################
# Page Content #
################

# draw the header to the page
require_once("includes/header.php");

# now the sidebar
require_once("includes/sidebar.php");

# now the login bar
require_once("includes/login_bar.php");

# validate the page
if ($_REQUEST["validator"]) {
	
        $validator = explode(".",$_REQUEST["validator"]);
        if ($validator[count($validator) - 1] != "php") {
                puke ("Page must be a php script");
        } else if (strpos($_REQUEST["validator"], "../") !== false || strpos($_REQUEST["validator"], "..\\") !== false) {
                puke ("No directory traversals");
        } else if (strpos($_REQUEST["validator"], "://") !== false) {
                puke ("No remote files");
        } else if (file_exists("validators/" . $_REQUEST["validator"])) {
                # remember the validator we are going to
                require_once("validators/" . $_REQUEST["validator"]);
        } else {
                puke ("No validator exists: " . $_REQUEST["validator"]);
        }
	
	require_once("validators/" . $_REQUEST["validator"]);
	define ('VALIDATOR', stripslashes($_REQUEST["validator"]));
}

# if we aren't going to a page, we're going to index.php
if ($_REQUEST["next_page"] == "") {
	$_REQUEST["next_page"]="index.php";
}

# the actual page content
if (count($errors) == 0) {
        $page = explode(".",$_REQUEST["next_page"]);
        if ($page[count($page) - 1] != "php") {
                puke ("Page must be a php script");
        } else if (strpos($_REQUEST["next_page"], "../") !== false || strpos($_REQUEST["next_page"], "..\\") !== false) {
                puke ("No directory traversals");
        } else if (strpos($_REQUEST["next_page"], "://") !== false) {
                puke ("No remote files");
        } else if (file_exists("pages/" . $_REQUEST["next_page"])) {
                # remember the page we are going to
                $_SESSION["prev_page"] = $_REQUEST["next_page"];
                require_once("pages/" . $_REQUEST["next_page"]);
        } else {
                puke ("No page exists: " . $_REQUEST["next_page"]);
        }
} else {
	# since there was an error, we must go back to the previous page
	require_once("pages/" . $_SESSION["prev_page"]);
}

# draw the page footer
require_once("includes/footer.php");

?>
